@@ -1,12 +1,40 @@
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![deny(missing_debug_implementations)]
 
-//! A database agnostic runtime query builder for Rust.
-//!
-//! SeaQuery is query builder to help you construct dynamic SQL queries in Rust. You can construct expressions, queries and schema as formal syntax trees using an ergonomic API. We support MySQL, Postgres and SQLite (WIP) behind a generic interface, while still offering engine specific features via extensions if you need them.
+//! <div align="center">
+//! 
+//!   <img src="https://raw.githubusercontent.com/SeaQL/sea-query/master/docs/SeaQL logo dual.png" width="320"/>
+//! 
+//!   <h1>SeaQuery</h1>
+//! 
+//!   <p>
+//!     <strong>A database agnostic runtime query builder for Rust</strong>
+//!   </p>
+//! 
+//!   [![crate](https://img.shields.io/crates/v/sea-query.svg)](https://crates.io/crates/sea-query)
+//!   [![docs](https://docs.rs/sea-query/badge.svg)](https://docs.rs/sea-query)
+//!   [![build status](https://github.com/SeaQL/sea-query/actions/workflows/rust.yml/badge.svg)](https://github.com/SeaQL/sea-query/actions/workflows/rust.yml)
+//! 
+//!   <sub>Built with ❤️ by 🌊🦀🐚</sub>
+//! 
+//! </div>
+//! 
+//! ## Introduction
+//! 
+//! SeaQuery is query builder to help you construct dynamic SQL queries in Rust.
+//! You can construct expressions, queries and schema as abstract syntax trees using an ergonomic API.
+//! We support MySQL, Postgres and SQLite behind a common interface that aligns their behaviour where appropriate.
 //! 
 //! This library is the foundation of upcoming projects: Document ORM (SeaORM) and Database Synchor (SeaHorse).
 //! 
+//! ## Install
+//! 
+//! ```toml
+//! # Cargo.toml
+//! [dependencies]
+//! sea-query = "*"
+//! ```
+//! 
 //! ## Usage
 //! 
 //! Table of Content
@@ -38,7 +66,8 @@
 //! 
 //! ### Drivers
 //! 
-//! We provide integration for [SQLx](https://crates.io/crates/sqlx) and [postgres](https://crates.io/crates/postgres).
+//! We provide integration for [SQLx](https://crates.io/crates/sqlx), 
+//! [postgres](https://crates.io/crates/postgres) and [rusqlite](https://crates.io/crates/rusqlite).
 //! See [examples](https://github.com/SeaQL/sea-query/blob/master/examples) for usage.
 //! 
 //! ### Iden
@@ -88,7 +117,7 @@
 //! ```rust
 //! # #[cfg(feature = "derive")]
 //! use sea_query::Iden;
-//!
+//! 
 //! // This will implement Iden exactly as shown above
 //! # #[cfg(feature = "derive")]
 //! #[derive(Iden)]
@@ -282,8 +311,8 @@
 //!     .foreign_key(
 //!         ForeignKey::create()
 //!             .name("FK_2e303c3a712662f1fc2a4d0aad6")
-//!             .table(Char::Table, Font::Table)
-//!             .col(Char::FontId, Font::Id)
+//!             .from(Char::Table, Char::FontId)
+//!             .to(Font::Table, Font::Id)
 //!             .on_delete(ForeignKeyAction::Cascade)
 //!             .on_update(ForeignKeyAction::Cascade)
 //!     )
@@ -438,8 +467,8 @@
 //! 
 //! let foreign_key = ForeignKey::create()
 //!     .name("FK_character_font")
-//!     .table(Char::Table, Font::Table)
-//!     .col(Char::FontId, Font::Id)
+//!     .from(Char::Table, Char::FontId)
+//!     .to(Font::Table, Font::Id)
 //!     .on_delete(ForeignKeyAction::Cascade)
 //!     .on_update(ForeignKeyAction::Cascade)
 //!     .to_owned();
@@ -549,6 +578,7 @@ pub mod tests_cfg;
 pub mod token;
 pub mod types;
 pub mod value;
+pub mod error;
 
 pub use backend::*;
 pub use driver::*;
