@@ -5,8 +5,8 @@ fn create_1() {
     assert_eq!(
         ForeignKey::create()
             .name("FK_2e303c3a712662f1fc2a4d0aad6")
-            .table(Char::Table, Font::Table)
-            .col(Char::FontId, Font::Id)
+            .from(Char::Table, Char::FontId)
+            .to(Font::Table, Font::Id)
             .on_delete(ForeignKeyAction::Cascade)
             .on_update(ForeignKeyAction::Cascade)
             .to_string(MysqlQueryBuilder),
